import 'package:businesslibrary/api/data_api.dart';
import 'package:businesslibrary/api/shared_prefs.dart';
import 'package:businesslibrary/data/company.dart';
import 'package:businesslibrary/data/govt_entity.dart';
import 'package:businesslibrary/data/purchase_order.dart';
import 'package:businesslibrary/data/supplier.dart';
import 'package:businesslibrary/data/user.dart';
import 'package:businesslibrary/util/find_supplier_page.dart';
import 'package:businesslibrary/util/snackbar_util.dart';
import 'package:flutter/material.dart';

class PurchaseOrderPage extends StatefulWidget {
  final String url;

  PurchaseOrderPage(this.url);

  @override
  _PurchaseOrderPageState createState() => _PurchaseOrderPageState();
}

class _PurchaseOrderPageState extends State<PurchaseOrderPage> {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();
  final GlobalKey<FormState> _formKey = new GlobalKey<FormState>();

  PurchaseOrder purchaseOrder = PurchaseOrder();
  User user;
  GovtEntity govtEntity;
  Company company;
  Supplier supplier;

  @override
  void initState() {
    super.initState();
    _getCachedPrefs();
  }

  _findSupplier() async {
    supplier = await Navigator.push(
      context,
      new MaterialPageRoute(builder: (context) => new FindSupplierPage()),
    );
    print('_PurchaseOrderPageState._findSupplier ${supplier.toJson()}');
    setState(() {});
  }

  _getCachedPrefs() async {
    user = await SharedPrefs.getUser();
    govtEntity = await SharedPrefs.getGovEntity();
    company = await SharedPrefs.getCompany();
  }

  _savePurchaseOrder() async {
    DataAPI api = DataAPI(widget.url);
    var key = await api.registerPurchaseOrder(purchaseOrder);
    if (key == '0') {
      AppSnackbar.showErrorSnackbar(
          context: context,
          scaffoldKey: _scaffoldKey,
          message: 'Error submitting purchase order',
          actionLabel: 'close');
    } else {
      AppSnackbar.showSnackbarWithAction(
          context: context,
          scaffoldKey: _scaffoldKey,
          message: 'Purchase Order submitted successfully',
          actionLabel: 'Done',
          backgroundColor: Colors.black,
          textColor: Colors.white,
          icon: Icons.done);
    }
  }

  _confirm() {
    showDialog(
        context: context,
        builder: (_) => new AlertDialog(
              title: new Text("Confirm Purchase Order"),
              content: new Text("Do you want to submit this Purchase Order?"),
              actions: <Widget>[
                GestureDetector(
                  onTap: _savePurchaseOrder,
                  child: Text('YES'),
                ),
                GestureDetector(
                  onTap: _cancel,
                  child: Text('NO'),
                ),
              ],
            ));
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: _scaffoldKey,
      appBar: AppBar(
        title: Text('Purchase Order'),
      ),
      body: Form(
        key: _formKey,
        child: new Padding(
          padding: const EdgeInsets.all(4.0),
          child: new Card(
            elevation: 6.0,
            child: new Padding(
              padding: const EdgeInsets.all(10.0),
              child: ListView(
                children: <Widget>[
                  new Padding(
                    padding: const EdgeInsets.only(top: 14.0),
                    child: Text(
                      'Purchase Order Details',
                      style: TextStyle(
                          color: Theme.of(context).accentColor,
                          fontSize: 14.0,
                          fontWeight: FontWeight.w900),
                    ),
                  ),
                  RaisedButton(
                    onPressed: _findSupplier,
                    color: Theme.of(context).accentColor,
                    child: Text(
                      'Find Supplier',
                      style: TextStyle(color: Colors.white),
                    ),
                  ),
                  TextFormField(
                    decoration: InputDecoration(
                      labelText: 'Purchase Order Number',
                    ),
                    keyboardType: TextInputType.text,
                    validator: (value) {
                      if (value.isEmpty) {
                        return 'Please enter PO number';
                      }
                    },
                    onSaved: (val) => purchaseOrder.purchaseOrderNumber = val,
                  ),
                  TextFormField(
                    decoration: InputDecoration(
                      labelText: 'Amount',
                    ),
                    keyboardType: TextInputType.number,
                    maxLength: 20,
                    validator: (value) {
                      if (value.isEmpty) {
                        return 'Please enter the amount';
                      }
                    },
                    onSaved: (val) => purchaseOrder.amount = val,
                  ),
                  new Padding(
                    padding: const EdgeInsets.only(
                        left: 28.0, right: 20.0, top: 30.0),
                    child: RaisedButton(
                      elevation: 8.0,
                      color: Theme.of(context).accentColor,
                      onPressed: _confirm,
                      child: new Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Text(
                          'Submit Purchase Order',
                          style: TextStyle(color: Colors.white, fontSize: 16.0),
                        ),
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        ),
      ),
      floatingActionButton: FloatingActionButton(
        elevation: 16.0,
        onPressed: _confirm,
        child: IconButton(
          icon: Icon(Icons.add),
          onPressed: _confirm,
        ),
      ),
    );
  }

  void _cancel() {
    print('_PurchaseOrderPageState._cancel');
  }
}
